Set alarms from your terminal.

## Installation
You can install this package using `pip` or `pipenv`.
The command `pylarm` will then be available from your terminal.

## Usage example

``` sh
pylarm --sound <PATH_TO_SOUND_FILE> --message='The time has come!' --at='17:00' &
```

You can also simply run
``` sh
pylarm --sound <PATH_TO_SOUND_FILE>
```
and you'll be prompted to select the time and the message.

To know the details about each option of the command `pylarm` run `pylarm --help`.


